# Convert GCode into 'Contours'

### Install
Should work for python 3.
```bash
pip install git+https://code.research.uts.edu.au/bigprint/gcode2contour.git
```

### Usage
Extract contours from a file.
```python
import gcode2contour as gc

contours = gc.decode_gcode("test.gcode")

print(contours[0].pos)
```

Calculate the dependency graph for the print.
This can be used to track the print and see which contours are available when not limited to a layer when printing.
```python
# This step may take a few minutes for larger/higher res prints
pt = gc.DependencyGraph(contours, 5, 5)

# contours which have their dependencies satisfied
c = pt.available_contours[0] # select first contour
c_id = pt.avail_contour_ids[0]

# Execute a contour
pt.do_contour(c_id)

# Other relevant fields include:
# .all_contours - full list of contours
# .done_contour_ids - contours which have been executed
# .layers - all_contours divided into lists for each layer
# .G - networkx DiGraph for dependencies -  pt.G.nodes[c_id]['layer'], or ['contour']
```

Plotting contours.
```python
# plot all the contours
gc.plot_contours(contours)

# plot one layer
gc.plot_contours2d(pt.layers[6])

# Plot 3 layers, each with a different color
gc.plot_contours(pt.layers[6], pt.layers[7], pt.layers[8], colors=['r','g','b'])
```

Manually feed gcode lines in to update the printer state.
```python
import gcode2contour as gc

printer = gc.machine()

line = "G1 X3.456 Y7.89 E1.234 F1200 ;linear segment"

# This changes the state of the printer by applying the gcode line
printer.read_gcode_line(line)

printer.get_state()
```
